@@ -1,6 +1,3 @@
-# imports - standard imports
-import sys
-
 # imports - module imports
 from pipupgrade.commands import command as main
 
