@@ -1,8 +1,8 @@
 # imports - module imports
-from pipupgrade.cli.util   import *
+from bpyutils.cli.util     import *
 from pipupgrade.cli.parser import get_args
-from pipupgrade.util._dict import merge_dict
-from pipupgrade.util.types import get_function_arguments
+from bpyutils.util._dict   import merge_dict
+from bpyutils.util.types   import get_function_arguments
 
 def command(fn):
     args    = get_args()
